//==============================================================================
//         Copyright 2003 - 2011   LASMEA UMR 6602 CNRS/Univ. Clermont II
//         Copyright 2009 - 2011   LRI    UMR 8623 CNRS/Univ Paris Sud XI
//
//          Distributed under the Boost Software License, Version 1.0.
//                 See accompanying file LICENSE.txt or copy at
//                     http://www.boost.org/LICENSE_1_0.txt
//==============================================================================
#ifndef NT2_CORE_SETTINGS_FORWARD_BUFFER_HPP_INCLUDED
#define NT2_CORE_SETTINGS_FORWARD_BUFFER_HPP_INCLUDED

/*!
  @file
  @brief Defines the buffer_ settings tag
**/

namespace nt2
{
  struct built_in_ {};

  namespace tag
  {
    /// @brief Option tag for buffer options
    struct buffer_;
} }

#endif
